@@ -28,7 +28,7 @@ class DBConnect():
         self.mongo_db = self.mongo_client[db]
         self.mongo_collection = self.mongo_db[collection]
 
-    def write_one_docu(self, docu: dict) -> bool:
+    def write_one_docu(self, docu: dict) -> str:
         try:
             if not docu.__contains__('creation_time'):
                 docu['creation_time'] = datetime.today()
@@ -46,13 +46,16 @@ class DBConnect():
         else:
             return False
 
-    def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> bool:
+    def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
         try:
             if many:
-                self.mongo_collection.update_many(find_docu, modify_docu)
+                student = self.mongo_collection.update_many(
+                    find_docu, modify_docu)
             else:
-                self.mongo_collection.update_one(find_docu, modify_docu)
-            return True
+                student = self.mongo_collection.update_one(
+                    find_docu, modify_docu)
+            # 返回匹配条数、受影响条数
+            return {'matched_count': student.matched_count, 'modified_count': student.modified_count}
         except Exception as err:
             str_data = 'MongoDB(组件)出现更新错误: {0}'.format(err)
             logging.warning(str_data)
@@ -113,9 +116,9 @@ class DBConnect():
         records_filtered = find_data.count()
         if not records_filtered:
             dict_data = {
-                'records_total': [],
+                'records_total': 0,
                 'records_filtered': 0,
-                'query_result': 0,
+                'query_result': [],
             }
             abort(Response(dict_data, 204, {}))
         if sort_list:
