@@ -9,7 +9,7 @@ logging.basicConfig(
 
 def handle_date(date: str, date_type='start') -> datetime:
     try:
-        if len(date) == 0:
+        if not date:
             date_data = None
         elif date.isdigit():
             date_time = date[:10]
